from setuptools import setup, find_packages

setup(
    name='type_gen_dict',
    version='0.0.4',
    author='Ray Del Vecchio',
    author_email='ray@cerebralvalley.ai',
    description='Python package to convert python dictionaries into other language types (Currently Typescript).',
    url="https://github.com/raydelvecchio/typegenerator",
    packages=find_packages(),
)